# rhosocial ActiveRecord 文档 / rhosocial ActiveRecord Documentation

欢迎使用 rhosocial ActiveRecord 文档！/ Welcome to the rhosocial ActiveRecord documentation!

## 可用语言 / Available Languages

- [English](en_US/README.md)
- [简体中文](zh_CN/README.md)

## 📋 实施状态总览 / Implementation Status Overview

> **⚠️ 开发状态通知 / DEVELOPMENT STATUS NOTICE**: 本文档集中包含已实现的功能和计划中的功能（假设功能）。某些部分描述的功能尚未提供。请参阅各个文档部分的具体实施状态指示，如"❌ 未实现/NOT IMPLEMENTED"，"⚠️ 部分实现/PARTIALLY IMPLEMENTED"或"🔄 已实现/IMPLEMENTED"。

### 当前实施状态 / Current Implementation Status
- **核心CRUD操作 / Core CRUD Operations**: ✅ Fully implemented
- **关系管理 / Relationship Management**: ✅ Implemented (basic relationships)
- **查询构建 / Query Building**: ✅ Implemented (basic to intermediate features)
- **异步支持 / Async Support**: ❌ Not implemented
- **跨数据库查询 / Cross-database Queries**: ❌ Not implemented
- **批量操作 / Batch Operations**: ❌ Not implemented
- **高级功能 / Advanced Features**: ⚠️ Partially implemented

有关每个功能的详细实施状态，请参阅具体文档部分。/ For detailed implementation status of each feature, please refer to the specific documentation sections.

## 关于 rhosocial ActiveRecord / About rhosocial ActiveRecord

**中文**：
rhosocial ActiveRecord 是一个现代的、Pythonic 的 ActiveRecord 模式实现，为数据库操作提供了优雅直观的接口，具有类型安全和丰富的功能。

详细信息请查看对应语言的文档。

**English**：
rhosocial ActiveRecord is a modern, Pythonic implementation of the ActiveRecord pattern, providing an elegant and intuitive interface for database operations with type safety and rich features.

Please refer to the documentation in your preferred language for detailed information.